@@ -31,10 +31,12 @@ captr_CHECKAUTH <- function() {
 #' 
 #' @param path path to specific API request URL 
 #' @param query query list 
+#' @param \dots Additional arguments passed to \code{\link[curl]{curl_fetch_memory}}.
+#' 
 #' @return list
 
 captr_GET <- 
-function(path, query) {
+function(path, query = NULL, ...) {
 
 	captr_CHECKAUTH()
 
@@ -42,7 +44,31 @@ function(path, query) {
     handle_setopt(h,  customrequest = "GET")
     handle_setheaders(h, "Captricity-API-Token" = Sys.getenv('CaptricityToken'))
 
-    tag_con    <- curl_fetch_memory(paste0("https://shreddr.captricity.com/api/v1/", path, query), handle=h)
+    tag_con    <- curl_fetch_memory(paste0("https://shreddr.captricity.com/api/v1/", path, query), handle=h, ...)
+    tag        <- fromJSON(rawToChar(tag_con$content))
+    tag
+}
+
+#'
+#' POST
+#' 
+#' @param path path to specific API request URL 
+#' @param query query list 
+#' @param \dots Additional arguments passed to \code{\link[curl]{curl_fetch_memory}}.
+#' 
+#' @return list
+
+captr_POST <- 
+function(path, query = NULL, ...) {
+
+	captr_CHECKAUTH()
+
+	h <- new_handle()
+    handle_setopt(h,  customrequest = "POST")
+    handle_setheaders(h, "Captricity-API-Token" = Sys.getenv('CaptricityToken'))
+    handle_setform(h, .list=query)
+
+    tag_con    <- curl_fetch_memory(paste0("https://shreddr.captricity.com/api/v1/", path), handle=h, ...)
     tag        <- fromJSON(rawToChar(tag_con$content))
     tag
 }
\ No newline at end of file
