@@ -4,13 +4,18 @@
 #' 
 #' @param batch_id ID for the batch
 #' @param path_to_image Path to the image you want OCRd
+#' @param \dots Additional arguments passed to \code{\link{captr_POST}}.
+#' 
+#' 
 #' @export
+#' 
 #' @references \url{https://shreddr.captricity.com/developer/}
+#' 
 #' @examples \dontrun{
 #' upload_image("batch_id", "path_to_image")
 #' }
 
-upload_image <- function(batch_id="", path_to_image="") {
+upload_image <- function(batch_id="", path_to_image="", ...) {
     
     captr_CHECKAUTH()
  
@@ -18,15 +23,10 @@ upload_image <- function(batch_id="", path_to_image="") {
         
     if (!file.exists(path_to_image)) stop("File Doesn't Exist. Please check the path.")
 
-    h <- new_handle()
-    handle_setopt(h,  customrequest = "POST")
-    handle_setheaders(h, "Captricity-API-Token" = Sys.getenv('CaptricityToken'))
-    handle_setform(h, uploaded_file = form_file(path_to_image))
+    query = list(uploaded_file = form_file(path_to_image))
+    res <- captr_POST(path=paste0("batch/", batch_id, "/batch-file/"), query,...)
 
-    tag_con    <- curl_fetch_memory(paste0("https://shreddr.captricity.com/api/v1/batch/", batch_id, "/batch-file/"), handle=h)
-    tag        <- fromJSON(rawToChar(tag_con$content))
-    tag
-    return(invisible(tag))
+    return(invisible(res))
 
 }
 
